# Distributed under the terms of the GNU General Public License v2

EAPI=7

inherit autotools

DESCRIPTION="An audio mixer that supports various file formats for SDL."
HOMEPAGE="https://libsdl.org/projects/SDL_mixer/"
SRC_URI="https://github.com/libsdl-org/SDL_mixer/tarball/171eb2d420d5643e4ee11514a06e04a41a463bbd -> SDL_mixer-2.8.1-171eb2d.tar.gz"

LICENSE="ZLIB"
SLOT="0"
KEYWORDS="*"
IUSE="flac fluidsynth libxmp midi mod modplug mp3 opus playtools static-libs timidity tremor vorbis +wav"
REQUIRED_USE="
	midi? ( || ( timidity fluidsynth ) )
	timidity? ( midi )
	fluidsynth? ( midi )
	mod? ( || ( modplug libxmp ) )
	modplug? ( mod )
	libxmp? ( mod )
	tremor? ( vorbis )
"

RDEPEND="
	media-libs/libsdl2
	flac? ( media-libs/flac )
	midi? (
		fluidsynth? ( media-sound/fluidsynth )
		timidity? ( media-sound/timidity++ )
	)
	mod? (
		modplug? ( media-libs/libmodplug )
		libxmp? ( media-libs/libxmp )
	)
	mp3? ( media-sound/mpg123 )
	opus? ( media-libs/opusfile )
	vorbis? (
		tremor? ( media-libs/tremor )
		!tremor? (
			media-libs/libvorbis
			media-libs/libogg 
		)
	)
"
DEPEND="${RDEPEND}"

post_src_unpack() {
	mv "${WORKDIR}"/libsdl-org-SDL_mixer-* "$S" || die
}

src_prepare() {
	default
	eautoreconf
}

src_configure() {
	local myeconfargs=(
		$(use_enable static-libs static)
		--disable-sdltest
		--enable-music-cmd
		$(use_enable wav music-wave)
		$(use_enable mod music-mod)
		$(use_enable modplug music-mod-modplug)
		--disable-music-mod-modplug-shared
		$(use_enable libxmp music-mod-xmp)
		--disable-music-mod-xmp-shared
		$(use_enable midi music-midi)
		$(use_enable timidity music-midi-timidity)
		$(use_enable fluidsynth music-midi-fluidsynth)
		--disable-music-midi-fluidsynth-shared
		$(use_enable tremor music-ogg-tremor)
		--disable-music-ogg-vorbis-shared
		$(use_enable flac music-flac)
		$(use_enable flac music-flac-libflac)
		$(use_enable mp3 music-mp3)
		$(use_enable mp3 music-mp3-mpg123)
		--disable-music-mp3-mpg123-shared
		$(use_enable opus music-opus)
		--disable-music-opus-shared
		LIBMIKMOD_CONFIG="${EPREFIX}"/usr/bin/${CHOST}-libmikmod-config
	)
	econf "${myeconfargs[@]}"
}

src_install() {
	emake DESTDIR="${D}" install
	dodoc {CHANGES,README}.txt
	find "${D}" -name '*.la' -delete || die
}

pkg_postinst() {
	# bug 412035
	# https://bugs.gentoo.org/show_bug.cgi?id=412035
	if use midi && use fluidsynth; then
		ewarn "FluidSynth support requires you to set the SDL_SOUNDFONTS"
		ewarn "environment variable to the location of a SoundFont file"
		ewarn "unless the game or application happens to do this for you."
		if use timidity; then
			ewarn "Failing to do so will result in Timidity being used instead."
		else
			ewarn "Failing to do so will result in silence."
		fi
	fi
}
